Predict a depth profile from a fitted Neural ODE
Source:R/piml_neural_ode.R
piml_neural_ode_predict.RdPredict a depth profile from a fitted Neural ODE

R/piml_neural_ode.R
piml_neural_ode_predict.RdPredict a depth profile from a fitted Neural ODE