Fit a DeepONet for depth-profile operators
Arguments
- depths
Numeric vector of depths (length
n_depths).- targets
Matrix of targets, shape
(n_obs, n_depths).- covariates
Matrix of per-site summary covariates, shape
(n_obs, p)– NOT a depth-dependent trajectory; each site is represented by a vector of static covariates. This is the canonical DeepONet setup where the branch input is a fixed- length vector.Integer hidden sizes for the branch and trunk MLPs.
- output_dim
Integer; dimension of the inner-product space (
pin the notes above).- epochs, lr
Training hyperparameters.
- seed
RNG seed.
- backend
"r"(default) or"torch"(full autograd).- device
"cpu","mps", or"cuda"whenbackend = "torch".